@@ -64,8 +64,8 @@ class Pool(object):
                 self.main.web3.toChecksumAddress(lp_account))
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateLpAccount(
@@ -82,8 +82,8 @@ class Pool(object):
     ):
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(current_pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool,'
+            self.main.web3.toChecksumAddress(current_pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateMigrationPool(migration_pool),
@@ -98,8 +98,8 @@ class Pool(object):
     ):
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateMigrateMode(migrateMode),
@@ -124,8 +124,8 @@ class Pool(object):
                 self.main.web3.toChecksumAddress(hedging_account))
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateHedgingAccount(
@@ -145,8 +145,8 @@ class Pool(object):
         List a new asset.
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.listAsset(token, cap),
@@ -164,8 +164,8 @@ class Pool(object):
         Update an asset's cap.
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateCap(token, cap),
@@ -180,8 +180,8 @@ class Pool(object):
     ):
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateTrading(stop),
@@ -196,8 +196,8 @@ class Pool(object):
     ):
 
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.updateFees(fees),
@@ -216,8 +216,8 @@ class Pool(object):
         Transfer postive equity balance to CeFi venue to rebalance pools. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
         return self.main.send_eth_transaction(
             method=contract.functions.transferAssets(
@@ -236,8 +236,8 @@ class Pool(object):
         Query pool name. Pool's name is the same as Lp token name. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getPoolName().call()
@@ -251,8 +251,8 @@ class Pool(object):
         Query signer address.
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getSigner().call()
@@ -268,8 +268,8 @@ class Pool(object):
         For eth, set token address to ZERO_ADDRESS
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getReserves(
@@ -286,8 +286,8 @@ class Pool(object):
         Query a token's hToken address associated with the pool. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getHToken(
@@ -304,8 +304,8 @@ class Pool(object):
         Query an account's withdraw limit. W.L is updated each week. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getWithdrawLimit(
@@ -322,8 +322,8 @@ class Pool(object):
         Query a public pools max capacity for an asset. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getCap(
@@ -340,8 +340,8 @@ class Pool(object):
         Check if asset is listed. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.assetListed(
@@ -358,8 +358,8 @@ class Pool(object):
         Query pool's total payout. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getNetPayout(
@@ -376,8 +376,8 @@ class Pool(object):
         Query pool's total payout. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getWithdrawalTimestamp(
@@ -395,8 +395,8 @@ class Pool(object):
         Query a liquidity provider's total payout. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.computeLpPayout(
@@ -415,8 +415,8 @@ class Pool(object):
         Query a liquidity provider's total payout. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool,'
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.computeBurnAmount(
@@ -434,8 +434,8 @@ class Pool(object):
         Query nonce associated with an account.
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getNonce(
@@ -452,8 +452,8 @@ class Pool(object):
         Query flag associated with a k-value for a pool.
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getFlag(k_value).call()
@@ -467,8 +467,8 @@ class Pool(object):
         Query migration pool address. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getMigrationPool().call()
@@ -482,8 +482,8 @@ class Pool(object):
         Check if pool is in migration mode. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowSpotPubPool.json'
+            'IHashflowSpotPubPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getMigrationMode().call()
@@ -497,8 +497,8 @@ class Pool(object):
         Query governance contract address. 
         '''
         contract = self.main.create_contract(
-            self.main.web3.toChecksumAddress(pool),
-            'abi/IHashflowPool.json'
+            'IHashflowPool',
+            self.main.web3.toChecksumAddress(pool)
         )
 
         result = contract.functions.getGovernance().call()
